#include "colors.inc"
#include "wine.inc"

global_settings {max_trace_level 10}

#declare REAL_WATER = 1
#declare GLASS = 1
#declare SNOW =1
#declare WINE_GLASSES=1
#declare MOUNTAINS=1
#declare STEAM=1

#declare winescale = <1.5, 1.5, 1.5>

#declare tubx = 144
#declare tuby = 48
#declare tubz = 144
#declare tubthick = 12
#declare tubround = 6
#declare railht = 2

#include "tub.inc"

object { 
	tub
	texture { tub_tex }
}

union {
	object { rail1 }
	object { rail2 }
	object { rail3 }
	object { rail4 }

	texture { rail_tex }
}

intersection {
	plane { < 0,1,0>, tuby-8 }
	object { tub_inside }
#ifdef (REAL_WATER)
	texture {
		pigment { rgbf <0.85,0.9,0.9,0.93> }
		finish {
			specular 0.8
			roughness 0.15
			refraction 1
			ior 1.33
			reflection 0.15
		} 
		normal {
			ripples
			frequency 10
			scale <tubx, tuby, tubz>
			translate <-tubx/2,0,-tubz/2>
		}
	}
#else 
	pigment { Green }
#end
}
#ifdef (WINE_GLASSES)

object { 
	glass 
#ifdef (GLASS)
	texture {glass_tex}
#else
	pigment { Blue }
#end
	scale winescale
	translate <tubx/2 -15, tuby+railht,tubz/2 -13 >
}

intersection {
	object { glass_contents }
	plane { <0,1,0>, 7.1 }
	texture { merlot }
	scale winescale
	translate <tubx/2 -15, tuby+railht,tubz/2 -13 >
}

object { 
	glass 
#ifdef (GLASS)
	texture {glass_tex}
#else
	pigment { Blue }
#end
	scale winescale
	translate <tubx/2 -5, tuby+railht,tubz/2 -10 >
}

intersection {
	object { glass_contents }
	plane { <0,1,0>, 8.25 }
	texture { merlot }
	scale winescale
	translate <tubx/2 -5, tuby+railht,tubz/2 -10 >
}

#end

plane {
	<0,1,0> 0
#ifdef (SNOW)
	texture {
		pigment { White}
		normal {
			bumps
			scale <250,250,250>
		}
	}
#else
	pigment { White}
#end
}

#declare milkyway=pigment {
	bozo
	color_map {
	  	[ 0.0 color rgbt <1,1,1,1>]
		[ 0.5 color rgbt <1,1,1,1>]
        	[ 0.5 color rgbt <1,1,1,1>]
        	[ 0.75 color Gray10 ]
 		[ 0.75 color Gray10 ]
		[ 1.0 color White]
      	}
	scale <0.002,0.01,0.002>
}

sky_sphere {
	pigment { color Black }
	pigment {
		bozo
      		color_map {
        		[ 0.0 0.85  color rgbt <1,1,1,1> color rgbt <1,1,1,1>]
        		[ 0.85 0.9  color rgbt <1,1,1,1> color Gray10 ]
		        [ 0.9 1.0  color Gray10 color White]
      		}
		scale <0.002,0.002,0.002>
    	}
	pigment  {
		gradient x
		triangle_wave
		pigment_map {
			[ 0.0 color rgbt <1,1,1,1>]
			[ 0.95 color rgbt <1,1,1,1>]
			[ 0.95 color rgbt <1,1,1,1>]
			[ 0.99 milkyway ]
			[ 0.99 milkyway ]
		}
		scale 2
		translate -1
		rotate z * 25 
		rotate y *60
	}
}

#ifdef (MOUNTAINS)

#declare mountaintex = texture {
	pigment { rgb < 0.35,0.16, 0.14 > }
	finish { diffuse 0.2 }
}

superellipsoid { 
	<0.75,0.25> 
	scale < 300 *36,  35 *36,  200 *36 > 
	translate <150*36, 0, 600*26>
	texture { mountaintex }
}

superellipsoid { 
	<0.75,0.25> 
	scale < 300 *36,  45 *36,  200 *36 > 
	translate <800*36, 0, 400*26>
	texture { mountaintex }
}
#end


light_source {
	<-20*36,20*36,-45*36>
	color rgb < 0.8,0.8,1.0>
}
#ifdef (REAL_WATER)
light_source {
	<tubx/2-tubthick-0.5,tuby/2,tubz/2-tubthick-36>,
	rgb <0.6,0.8,1>
}
#end

#ifdef (STEAM)
#declare sf=3
cylinder {
	<0,-0.5,0>,
	<0,0.5,0>, 0.5
	hollow
	halo {
		attenuating
		cylindrical_mapping
		linear
		color_map {
			[0 rgbt <1,1,1,1>]
			[0.25 rgbt <1,1,1,1>]
			[1 rgbt <1,1,1,-1>]
		}
		aa_level 4
		aa_threshold 0.1
		scale <0.25,0.25,0.25>
		turbulence <0.5, 0,0.5>
	}
	pigment { rgbf <1,1,1,1> }
	scale <sf*12,sf*12,sf*12>
	translate <tubx/2-tubthick-sf*10,tuby+railht+sf*12/2,tubz/2-tubthick-sf*8>
}
cylinder {
	<0,-0.5,0>,
	<0,0.5,0>, 0.5
	hollow
	halo {
		attenuating
		cylindrical_mapping
		linear
		color_map {
			[0 rgbt <1,1,1,1>]
			[0.25 rgbt <1,1,1,1>]
			[1 rgbt <1,1,1,-1>]
		}
		scale <0.25,0.25,0.25>
		turbulence <0.5, 0,0.5>
	}
	pigment { rgbf <1,1,1,1> }
	scale <sf*12,sf*12,sf*12>
	translate <tubx/2-tubthick-sf*3,tuby+railht+sf*12/2,tubz/2-tubthick-sf*12*3/4>
}

#end

camera {
//	location <-40, 36, -40>
//	look_at <-60,12,-60>
//	location <0, 120, 0>
//	look_at <-60,12,-60>
//	location <66,60,55>
//	look_at <66,0,55>
	location <30,58,28.37>
	up <0,1,0>
	right <1.4981273,0,0>
	look_at <60,60,60>

}
